@@ -708,7 +708,7 @@ class Spin(Collection):
     err_DEC0: List[Optional[float]] = [np.nan]
     period: List[Optional[float]] = [np.nan]
     err_period: List[Optional[float]] = [np.nan]
-    period_flag: List[Optional[float]] = [np.nan]
+    period_flag: List[Optional[str]] = [""]
     period_type: List[Optional[str]] = [""]
     long_: List[Optional[float]] = pydantic.Field([np.nan], alias="long")
     lat: List[Optional[float]] = [np.nan]
