@@ -13,14 +13,16 @@ import requests
 from rich.progress import Progress
 
 from rocks import cli
+from rocks import config
 from rocks import index
 from rocks.logging import logger
 
 # Run asyncio nested for jupyter notebooks, GUIs, ...
 nest_asyncio.apply()
 
+
 def get_or_create_eventloop():
-    """ Enable asyncio to get the event loop in a thread other than the main thread
+    """Enable asyncio to get the event loop in a thread other than the main thread
 
     Returns
     --------
@@ -34,6 +36,7 @@ def get_or_create_eventloop():
             asyncio.set_event_loop(loop)
             return asyncio.get_event_loop()
 
+
 def identify(id_, return_id=False, local=True, progress=False):
     """Resolve names and numbers of one or more minor bodies using identifiers.
 
@@ -63,6 +66,10 @@ def identify(id_, return_id=False, local=True, progress=False):
     the asteroid is unnumbered, its number is np.nan.
     """
 
+    # Ensure the asteroid name-number index exists
+    if not config.PATH_INDEX.is_dir():
+        index._ensure_index_exists()
+
     # ------
     # Verify input
     if isinstance(id_, (str, int, float)):
@@ -345,11 +352,11 @@ async def _query_quaero(id_, session):
         return None
 
     if "data" not in response.keys():  # no match found
-        logger.warning(f"Could not find match for id {id_}.")
+        logger.error(f"Could not find match for id {id_}.")
         return False
 
     elif not response["data"]:  # empty response
-        logger.warning(f"Could not find match for id {id_}.")
+        logger.error(f"Could not find match for id {id_}.")
         return False
 
     return response
